==> haskell-zip-archive-0.3.3-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-zip-archive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: zip-archive
version: 0.3.3
id: zip-archive-0.3.3-Gc0FdRl2jOXJN0CXoN9JTn
key: zip-archive-0.3.3-Gc0FdRl2jOXJN0CXoN9JTn
license: BSD-3-Clause
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: http://github.com/jgm/zip-archive
synopsis: Library for creating and modifying zip archives.
description:
    The zip-archive library provides functions for creating, modifying,
    and extracting files from zip archives.
category: Codec
abi: c60e5bb7144cb659261d8512ca8c41e7
exposed: True
exposed-modules:
    Codec.Archive.Zip
import-dirs: /usr/lib/ghc-8.6.1/site-local/zip-archive-0.3.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/zip-archive-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/zip-archive-0.3.3
hs-libraries: HSzip-archive-0.3.3-Gc0FdRl2jOXJN0CXoN9JTn
depends:
    array-0.5.2.0 base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    containers-0.6.0.1 digest-0.0.1.2-EmnqrtISorTAzGzJuIqcyN
    directory-1.3.3.0 filepath-1.4.2.1 mtl-2.2.2 pretty-1.1.3.6
    text-1.2.3.1 time-1.8.0.2 unix-2.7.2.2
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-zip-archive/html/zip-archive.haddock
haddock-html: /usr/share/doc/haskell-zip-archive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zip-archive-0.3.3-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-zip-archive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: zip-archive
version: 0.3.3
id: zip-archive-0.3.3-FtEZ8cVpsWW1rhccfBNhic
key: zip-archive-0.3.3-FtEZ8cVpsWW1rhccfBNhic
license: BSD-3-Clause
maintainer: jgm@berkeley.edu
author: John MacFarlane
homepage: http://github.com/jgm/zip-archive
synopsis: Library for creating and modifying zip archives.
description:
    The zip-archive library provides functions for creating, modifying,
    and extracting files from zip archives.
category: Codec
abi: cbb18d0233b1d56bda1b3da06cc05cfa
exposed: True
exposed-modules:
    Codec.Archive.Zip
import-dirs: /usr/lib/ghc-8.6.2/site-local/zip-archive-0.3.3
library-dirs: /usr/lib/ghc-8.6.2/site-local/zip-archive-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/zip-archive-0.3.3
hs-libraries: HSzip-archive-0.3.3-FtEZ8cVpsWW1rhccfBNhic
depends:
    array-0.5.3.0 base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    containers-0.6.0.1 digest-0.0.1.2-EmnqrtISorTAzGzJuIqcyN
    directory-1.3.3.0 filepath-1.4.2.1 mtl-2.2.2 pretty-1.1.3.6
    text-1.2.3.1 time-1.8.0.2 unix-2.7.2.2
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-zip-archive/html/zip-archive.haddock
haddock-html: /usr/share/doc/haskell-zip-archive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
